@@ -90,6 +90,7 @@ symlink_mesa_main() {
     action api_validate.h
     action attrib.c
     action attrib.h
+    action bitset.h
     action blend.c
     action blend.h
     action bufferobj.c
@@ -168,6 +169,8 @@ symlink_mesa_main() {
     action polygon.h
     action rastpos.c
     action rastpos.h
+    action rbadaptors.c
+    action rbadaptors.h
     action renderbuffer.c
     action renderbuffer.h
     action simple_list.h
