@@ -1,4 +1,4 @@
-/* $XdotOrg: xserver/xorg/hw/xfree86/common/xf86Config.c,v 1.23.2.4 2006/04/07 01:37:03 ajax Exp $ */
+/* $XdotOrg: xserver/xorg/hw/xfree86/common/xf86Config.c,v 1.33 2006/06/02 12:05:32 daniels Exp $ */
 /* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Config.c,v 3.276 2003/10/08 14:58:26 dawes Exp $ */
 
 
@@ -249,8 +249,9 @@ xf86ValidateFontPath(char *path)
 char **
 xf86ModulelistFromConfig(pointer **optlist)
 {
-    int count = 0;
+    int count = 0, i = 0;
     char **modulearray;
+    char *ignore[] = { "GLcore", "speedo", "bitmap", NULL };
     pointer *optarray;
     XF86LoadPtr modp;
     
@@ -271,7 +272,12 @@ xf86ModulelistFromConfig(pointer **optlist)
 	 */
 	modp = xf86configptr->conf_modules->mod_load_lst;
 	while (modp) {
-	    count++;
+            for (i = 0; ignore[i]; i++) {
+                if (strcmp(modp->load_name, ignore[i]) == 0)
+                    modp->ignore = 1;
+            }
+            if (!modp->ignore)
+	        count++;
 	    modp = (XF86LoadPtr) modp->list.next;
 	}
     }
@@ -287,9 +293,11 @@ xf86ModulelistFromConfig(pointer **optlist)
     if (xf86configptr->conf_modules) {
 	modp = xf86configptr->conf_modules->mod_load_lst;
 	while (modp) {
-	    modulearray[count] = modp->load_name;
-	    optarray[count] = modp->load_opt;
-	    count++;
+            if (!modp->ignore) {
+	        modulearray[count] = modp->load_name;
+	        optarray[count] = modp->load_opt;
+	        count++;
+            }
 	    modp = (XF86LoadPtr) modp->list.next;
 	}
     }
@@ -510,7 +518,7 @@ GenerateDriverlist(char * dirname, char * drivernames)
     ret = LoaderListDirs(subdirs, patlist);
     
     /* fix up the probe order for video drivers */
-    if (strstr(dirname, "drivers"))
+    if (strstr(dirname, "drivers") && ret != NULL)
         fixup_video_driver_list(ret);
 
     return ret;
@@ -1323,7 +1331,7 @@ configInputKbd(IDevPtr inputp)
 
 #define NULL_IF_EMPTY(s) (s[0] ? s : (xfree(s), (char *)NULL))
 
-  if (!noXkbExtension && !XkbInitialMap) {
+  if (!noXkbExtension) {
     if ((s = xf86SetStrOption(inputp->commonOptions, "XkbKeymap", NULL))) {
       xf86Info.xkbkeymap = NULL_IF_EMPTY(s);
       xf86Msg(X_CONFIG, "XKB: keymap: \"%s\" "
