@@ -69,7 +69,7 @@ typedef struct _DevToConfig {
 static DevToConfigPtr DevToConfig = NULL;
 static int nDevToConfig = 0, CurrentDriver;
 
-xf86MonPtr ConfiguredMonitor;
+_X_EXPORT xf86MonPtr ConfiguredMonitor;
 Bool xf86DoConfigurePass1 = TRUE;
 Bool foundMouse = FALSE;
 
@@ -87,7 +87,7 @@ static char *DFLT_MOUSE_DEV = "/dev/mouse";
 #elif defined(__QNXNTO__)
 static char *DFLT_MOUSE_PROTO = "OSMouse";
 static char *DFLT_MOUSE_DEV = "/dev/devi/mouse0";
-#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
 static char *DFLT_MOUSE_DEV = "/dev/sysmouse";
 static char *DFLT_MOUSE_PROTO = "auto";
 #else
@@ -251,7 +251,7 @@ xf86AddBusDeviceToConfigure(const char *driver, BusType bus, void *busData, int
 /*
  * Backwards compatibility
  */
-GDevPtr
+_X_EXPORT GDevPtr
 xf86AddDeviceToConfigure(const char *driver, pciVideoPtr pVideo, int chipset)
 {
     return xf86AddBusDeviceToConfigure(driver, pVideo ? BUS_PCI : BUS_ISA,
@@ -317,11 +317,9 @@ configureInputSection (void)
 #ifndef __SCO__
     mouse->inp_option_lst = 
 		xf86addNewOption(mouse->inp_option_lst, "Device", DFLT_MOUSE_DEV);
-#ifndef __UNIXWARE__
+#endif
     mouse->inp_option_lst = 
 		xf86addNewOption(mouse->inp_option_lst, "ZAxisMapping", "4 5 6 7");
-#endif
-#endif
     ptr = (XF86ConfInputPtr)xf86addListItem((glp)ptr, (glp)mouse);
     return ptr;
 }
@@ -627,10 +625,8 @@ configureModuleSection (void)
     	    module = xf86confmalloc(sizeof(XF86LoadRec));
     	    memset((XF86LoadPtr)module,0,sizeof(XF86LoadRec));
     	    module->load_name = *el;
-	    /* HACK, remove GLcore, glx, loads it as a submodule */
-	    if (strcmp(*el, "GLcore"))
-	    	ptr->mod_load_lst = (XF86LoadPtr)xf86addListItem(
-					(glp)ptr->mod_load_lst, (glp)module);
+            ptr->mod_load_lst = (XF86LoadPtr)xf86addListItem(
+                                (glp)ptr->mod_load_lst, (glp)module);
     	}
 	xfree(elist);
     }
@@ -651,9 +647,7 @@ configureModuleSection (void)
 		(strcmp(*el, "freetype")  == 0 &&
 		 strstr(defaultFontPath, "/TTF")) ||
     	        (strcmp(*el, "type1")  == 0 &&
-		 strstr(defaultFontPath, "/Type1")) ||
-    	        (strcmp(*el, "speedo") == 0 &&
-		 strstr(defaultFontPath, "/Speedo"))))
+		 strstr(defaultFontPath, "/Type1")))) 
 	    	ptr->mod_load_lst = (XF86LoadPtr)xf86addListItem(
 					(glp)ptr->mod_load_lst, (glp)module);
     	}
