@@ -1,5 +1,5 @@
 /* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Init.c,v 3.212 2004/01/27 01:31:45 dawes Exp $ */
-/* $XdotOrg: xserver/xorg/hw/xfree86/common/xf86Init.c,v 1.33.2.1 2006/04/04 14:16:56 ajax Exp $ */
+/* $XdotOrg: xserver/xorg/hw/xfree86/common/xf86Init.c,v 1.37 2006/06/01 19:37:53 ajax Exp $ */
 
 /*
  * Loosely based on code bearing the following copyright:
@@ -93,11 +93,6 @@
 
 #include "globals.h"
 
-#ifdef XTESTEXT1
-#include "atKeynames.h"
-extern int xtest_command_key;
-#endif /* XTESTEXT1 */
-
 #ifdef DPMSExtension
 #define DPMS_SERVER
 #include <X11/extensions/dpms.h>
@@ -121,7 +116,6 @@ void (*xf86OSPMClose)(void) = NULL;
 
 #ifdef XFree86LOADER
 static char *baseModules[] = {
-	"bitmap",
 	"pcidata",
 	NULL
 };
@@ -1038,9 +1032,6 @@ InitInput(argc, argv)
 
     xf86Info.vtRequestsPending = FALSE;
     xf86Info.inputPending = FALSE;
-#ifdef XTESTEXT1
-    xtest_command_key = KEY_Begin + MIN_KEYCODE;
-#endif /* XTESTEXT1 */
 
     if (serverGeneration == 1) {
 	/* Call the PreInit function for each input device instance. */
@@ -1905,11 +1896,7 @@ xf86RunVtInit(void)
           FatalError("xf86RunVtInit: fork failed (%s)\n", strerror(errno));
           break;
       case 0:  /* child */
-	  if (setuid(getuid()) == -1) {
-	      xf86Msg(X_ERROR, "xf86RunVtInit: setuid failed (%s)\n",
-			 strerror(errno));
-	      exit(255);
-	  }
+          setuid(getuid());
           /* set stdin, stdout to the consoleFd */
           for (i = 0; i < 2; i++) {
             if (xf86Info.consoleFd != i) {
