@@ -323,7 +323,6 @@ LOOKUP xfree86LookupTab[] = {
     SYMFUNC(xf86SetCurrentAccess)
     SYMFUNC(xf86IsPrimaryPci)
     SYMFUNC(xf86IsPrimaryIsa)
-    SYMFUNC(xf86CheckPciGAType)
     SYMFUNC(xf86PrintResList)
     SYMFUNC(xf86AddResToList)
     SYMFUNC(xf86JoinResLists)
@@ -614,7 +613,13 @@ LOOKUP xfree86LookupTab[] = {
     SYMFUNC(xf86GetGammaRamp)
     SYMFUNC(xf86ChangeGammaRamp)
 
+    /* xf86RandR.c */
+#ifdef RANDR
+    SYMFUNC(xf86RandRSetNewVirtualAndDimensions)
+#endif
+
     /* xf86xv.c */
+#ifdef XV
     SYMFUNC(xf86XVScreenInit)
     SYMFUNC(xf86XVRegisterGenericAdaptorDriver)
     SYMFUNC(xf86XVListGenericAdaptors)
@@ -631,6 +636,7 @@ LOOKUP xfree86LookupTab[] = {
     SYMFUNC(xf86XvMCScreenInit)
     SYMFUNC(xf86XvMCCreateAdaptorRec)
     SYMFUNC(xf86XvMCDestroyAdaptorRec)
+#endif
 
     /* xf86VidMode.c */
     SYMFUNC(VidModeExtensionInit)
@@ -702,6 +708,7 @@ LOOKUP xfree86LookupTab[] = {
     SYMFUNC(xf86MotionHistoryAllocate)
     SYMFUNC(xf86FirstLocalDevice)
     SYMFUNC(xf86eqEnqueue)
+    SYMFUNC(xf86ActivateDevice)
 /* The following segment merged from Metrolink tree */
     SYMFUNC(xf86XInputSetScreen)
     SYMFUNC(xf86ScaleAxis)
@@ -755,6 +762,7 @@ LOOKUP xfree86LookupTab[] = {
     SYMFUNC(LoaderListDirs)
     SYMFUNC(LoaderFreeDirList)
     SYMFUNC(LoaderGetOS)
+    SYMFUNC(LoaderGetABIVersion)
 
     /*
      * These are our own interfaces to libc functions.
