@@ -218,13 +218,7 @@ XAADoComposite (
 
     if (pDst->alphaMap || pSrc->alphaMap || (pMask && pMask->alphaMap))
 	return FALSE;
-
-    if ((pSrc->repeat && pSrc->repeatType != RepeatNormal) ||
-	(pMask && pMask->repeat && pMask->repeatType != RepeatNormal))
-    {
-	return FALSE;
-    }
-
+	
     xDst += pDst->pDrawable->x;
     yDst += pDst->pDrawable->y;
     xSrc += pSrc->pDrawable->x;
@@ -513,12 +507,19 @@ XAAComposite (CARD8      op,
     XAAInfoRecPtr infoRec = GET_XAAINFORECPTR_FROM_SCREEN(pScreen);
     XAA_RENDER_PROLOGUE(pScreen, Composite);
 
-    if((op == PictOpSrc) && !pMask && infoRec->pScrn->vtSema &&
-	infoRec->ScreenToScreenBitBlt &&
-        pSrc->pDrawable &&
-	DRAWABLE_IS_ON_CARD(pSrc->pDrawable) &&
-	DRAWABLE_IS_ON_CARD(pDst->pDrawable) &&
-	!pSrc->transform && !pSrc->repeat && (pSrc->format == pDst->format))
+    if(!pMask && infoRec->pScrn->vtSema &&
+       infoRec->ScreenToScreenBitBlt &&
+       pSrc->pDrawable &&
+       DRAWABLE_IS_ON_CARD(pSrc->pDrawable) &&
+       DRAWABLE_IS_ON_CARD(pDst->pDrawable) &&
+       !pSrc->transform &&
+       (!pSrc->repeat || (xSrc >= 0 && ySrc >= 0 &&
+			  xSrc+width<=pSrc->pDrawable->width &&
+			  ySrc+height<=pSrc->pDrawable->height)) &&
+       ((op == PictOpSrc && pSrc->format == pDst->format) ||
+	(op == PictOpOver && !pSrc->alphaMap && !pDst->alphaMap &&
+	 pSrc->format==pDst->format &&
+	 (pSrc->format==PICT_x8r8g8b8 || pSrc->format==PICT_x8b8g8r8))))
     {
 	XAACompositeSrcCopy(pSrc, pDst, xSrc, ySrc, xDst, yDst, width, height);
     } else if(!pSrc->pDrawable || (pMask && !pMask->pDrawable) ||
